summaryrefslogtreecommitdiff
path: root/include/apr_proc_mutex.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/apr_proc_mutex.h')
-rw-r--r--include/apr_proc_mutex.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/include/apr_proc_mutex.h b/include/apr_proc_mutex.h
index 4c0f92bc0..15312b2bd 100644
--- a/include/apr_proc_mutex.h
+++ b/include/apr_proc_mutex.h
@@ -119,10 +119,12 @@ APR_DECLARE(apr_status_t) apr_proc_mutex_trylock(apr_proc_mutex_t *mutex);
* Attempt to acquire the lock for the given mutex until timeout expires.
* If the acquisition time outs, the call returns with APR_TIMEUP.
* @param mutex the mutex on which to attempt the lock acquiring.
* @param timeout the relative timeout (microseconds)
*/
APR_DECLARE(apr_status_t) apr_proc_mutex_timedlock(apr_proc_mutex_t *mutex,
- apr_time_t timeout);
+ apr_time_t timeout,
+ int absolute);
/**
* Release the lock for the given mutex.
@@ -119,10 +119,12 @@ APR_DECLARE(apr_status_t) apr_proc_mutex_trylock(apr_proc_mutex_t *mutex);
* If the acquisition time outs, the call returns with APR_TIMEUP.
* @param mutex the mutex on which to attempt the lock acquiring.
- * @param timeout the relative timeout (microseconds)
+ * @param timeout the absolute time or relative timeout (microseconds)
+ * @param absolute whether the timeout given is absolute (!0) or relative (0)
*/
APR_DECLARE(apr_status_t) apr_proc_mutex_timedlock(apr_proc_mutex_t *mutex,